BrowserStringParser.Result (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class BrowserStringParser.Result

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.BrowserStringParser.Result

Enclosing class:
  BrowserStringParser

    public class BrowserStringParser.Result

extends java.lang.Object

Constructor Summary
`BrowserStringParser.Result(boolean match)`
`BrowserStringParser.Result(boolean match, java.lang.String customLauncher)`

Method Summary
`java.lang.String` | `customLauncher()`
`boolean` | `match()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### BrowserStringParser.Result

    public BrowserStringParser.Result(boolean match,
                                      java.lang.String customLauncher)

### BrowserStringParser.Result

    public BrowserStringParser.Result(boolean match)

Method Detail

### match

    public boolean match()

### customLauncher

    public java.lang.String customLauncher()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.